@@ -23,13 +23,13 @@ convertUSGSHUC8 <- function(nameOnly=FALSE) {
   url <- 'http://water.usgs.gov/GIS/dsdl/huc250k_shp.zip'
   
   filePath <- paste(dataDir,basename(url),sep='/')
-  download.file(url,filePath)
-  unzip(filePath,exdir=dataDir)
+  utils::download.file(url,filePath)
+  utils::unzip(filePath,exdir=dataDir)
         
   # Convert shapefile into SpatialPolygonsDataFrame
   dsnPath <- paste0(dataDir, '/huc250k_shp')
   shpName <- 'huc250k'
-  spDF <- convertLayer(dsn=dsnPath,layerName=shpName)
+  SPDF <- convertLayer(dsn=dsnPath,layerName=shpName)
 
   # Rationalize naming:
   # * human readable full nouns with descriptive prefixes
@@ -40,43 +40,43 @@ convertUSGSHUC8 <- function(nameOnly=FALSE) {
   # * longitude (decimal degrees E)
   # * latitude (decimal degrees N)
   
-  #   names(spDF)
+  #   names(SPDF)
   #   [1] "AREA"       "PERIMETER"  "HUC250K_"   "HUC250K_ID" "HUC_CODE"   "HUC_NAME"   "REG"       
   #   [8] "SUB"        "ACC"        "CAT"       
   
   # Subset this dataframe to include only obviously useful columns
   usefulColumns <- c('AREA','HUC_CODE','HUC_NAME')
-  spDF <- spDF[,usefulColumns]
-  names(spDF) <- c('area','HUC','HUCName')
+  SPDF <- SPDF[,usefulColumns]
+  names(SPDF) <- c('area','HUC','HUCName')
 
   # Group polygons with duplicated hydrologic unit codes
-  spDF <- organizePolygons(spDF, uniqueID='HUC', sumColumns='area')
+  SPDF <- organizePolygons(SPDF, uniqueID='HUC', sumColumns='area')
 
   # NOTE:  Area appears to be in units of m^2
   # NOTE:  Puyallup = 2566209748 ~= 2455 km^2 from Wikipedia
   
   # Calculate centroids to help add more metadata
-  centroids <- rgeos::gCentroid(spDF, byid=TRUE)
+  centroids <- rgeos::gCentroid(SPDF, byid=TRUE)
   lon <- sp::coordinates(centroids)[,1]
   lat <- sp::coordinates(centroids)[,2]
   
   # Add more standard columns
-  spDF$longitude <- lon
-  spDF$latitude <- lat  
-  spDF$countryCode <- 'US'
-  spDF$countryName <- 'United States'
-  # NOTE: Using getStateCode() with centroids causes 37 locations be in a body of water resulting in 'NA'
-  suppressWarnings(spDF$stateCode <- getStateCode(lon, lat))
-  spDF$stateName <- codeToState(spDF$stateCode, spDF$countryCode)
+  SPDF$longitude <- lon
+  SPDF$latitude <- lat  
+  SPDF$countryCode <- 'US'
+  SPDF$countryName <- 'United States'
+  # NOTE: Using getStateCode() with centroids 
+  suppressWarnings(SPDF$stateCode <- getStateCode(lon, lat, countryCodes=c('US')))
+  SPDF$stateName <- codeToState(SPDF$stateCode, SPDF$countryCode)
    
   # Assign a name and save the data
-  assign(datasetName,spDF)
+  assign(datasetName,SPDF)
   save(list=c(datasetName),file=paste0(dataDir,"/",datasetName, '.RData'))
   
   # Clean up
   unlink(filePath, force=TRUE)
   unlink(dsnPath, recursive=TRUE, force=TRUE)
   
-  invisible(datasetName)
+  return(invisible(datasetName))
 }
 
